@@ -127,21 +127,21 @@ class Figure(PlotDataObject):
         formats.append(ExportFormat(selector="html", extension="html", method_name="to_html_stream", text=False))
         return formats
 
-    def _to_html(self, debug_mode: bool = False, canvas_id: str = 'canvas', version: str = None):
-        lib_path = plot_data_path(debug_mode=debug_mode, version=version)
+    def _to_html(self, local: bool = False, canvas_id: str = 'canvas', version: str = None):
+        lib_path = plot_data_path(local=local, version=version)
         return self.template.substitute(data=json.dumps(self.to_dict()), core_path=lib_path, canvas_id=canvas_id,
                                         width=self.width, height=self.height)
 
-    def to_html_stream(self, stream, debug_mode: bool = False, canvas_id: str = 'canvas', version: str = None):
+    def to_html_stream(self, stream, local: bool = False, canvas_id: str = 'canvas', version: str = None):
         """ Export current Figure to its equivalent html stream file. """
-        html = self._to_html(debug_mode=debug_mode, canvas_id=canvas_id, version=version)
+        html = self._to_html(local=local, canvas_id=canvas_id, version=version)
         stream.write(html)
 
-    def to_html(self, filepath: str = None, debug_mode: bool = False, canvas_id: str = 'canvas', version: str = None):
+    def to_html(self, filepath: str = None, local: bool = False, canvas_id: str = 'canvas', version: str = None):
         """ Export current Figure to an HTML file given by the filepath. """
         filepath = make_filepath(filepath=filepath)
         with open(filepath, 'w', encoding="utf-8") as file:
-            self.to_html_stream(file, debug_mode=debug_mode, canvas_id=canvas_id, version=version)
+            self.to_html_stream(file, local=local, canvas_id=canvas_id, version=version)
         return filepath
 
     def plot_data(self, **kwargs):
@@ -160,20 +160,11 @@ class ReferencedObject(PlotDataObject):
         super().__init__(type_=type_, name=name)
 
 
-class Shape(ReferencedObject):
-    """ Shape object. """
-
-    def __init__(self, type_: str, reference_path: str = "#", tooltip: str = None, name: str = ""):
-        self.tooltip = tooltip
-        super().__init__(type_=type_, reference_path=reference_path, name=name)
-
-
 class Sample(ReferencedObject):
     """ Graph Point. """
 
     def __init__(self, values, reference_path: str = "#", name: str = ""):
         self.values = values
-        self.reference_path = reference_path
         super().__init__(type_="sample", reference_path=reference_path, name=name)
 
     def to_dict(self, use_pointers: bool = True, memo=None, path: str = '#', id_method=True,
@@ -435,7 +426,7 @@ class PointFamily(PlotDataObject):
         PlotDataObject.__init__(self, type_=None, name=name)
 
 
-class Text(Shape):
+class Text(ReferencedObject):
     """
     A class for displaying texts on canvas. Text is a primitive and can be instantiated by PrimitiveGroup.
 
@@ -459,7 +450,7 @@ class Text(Shape):
 
     def __init__(self, comment: str, position_x: float, position_y: float, text_style: TextStyle = None,
                  text_scaling: bool = None, max_width: float = None, height: float = None, multi_lines: bool = True,
-                 reference_path: str = "#", tooltip: str = None, name: str = ''):
+                 reference_path: str = "#", name: str = ''):
         self.comment = comment
         self.text_style = text_style
         self.position_x = position_x
@@ -468,7 +459,7 @@ class Text(Shape):
         self.max_width = max_width
         self.height = height
         self.multi_lines = multi_lines
-        super().__init__(type_='text', reference_path=reference_path, tooltip=tooltip, name=name)
+        super().__init__(type_='text', reference_path=reference_path, name=name)
 
     def mpl_plot(self, ax=None, color='k', alpha=1., **kwargs):
         """ Plots using Matplotlib. """
@@ -478,7 +469,7 @@ class Text(Shape):
         return ax
 
 
-class Line2D(Shape):
+class Line2D(ReferencedObject):
     """
     An infinite line. Line2D is a primitive and can be instantiated by PrimitiveGroups.
 
@@ -491,12 +482,12 @@ class Line2D(Shape):
     """
 
     def __init__(self, point1: List[float], point2: List[float], edge_style: EdgeStyle = None,
-                 reference_path: str = "#", tooltip: str = None, name: str = ''):
+                 reference_path: str = "#", name: str = ''):
         self.data = point1 + point2  # Retrocompatibility
         self.point1 = point1
         self.point2 = point2
         self.edge_style = edge_style
-        super().__init__(type_='line2d', reference_path=reference_path, tooltip=tooltip, name=name)
+        super().__init__(type_='line2d', reference_path=reference_path, name=name)
 
     def mpl_plot(self, ax=None, edge_style=None, **kwargs):
         """ Plots using matplotlib. """
@@ -514,7 +505,7 @@ class Line2D(Shape):
         return ax
 
 
-class LineSegment2D(Shape):
+class LineSegment2D(ReferencedObject):
     """
     A line segment. This is a primitive that can be called by PrimitiveGroup.
 
@@ -527,7 +518,7 @@ class LineSegment2D(Shape):
     """
 
     def __init__(self, point1: List[float], point2: List[float], edge_style: EdgeStyle = None,
-                 reference_path: str = "#", tooltip: str = None, name: str = ''):
+                 reference_path: str = "#", name: str = ''):
         # Data is used in typescript
         self.data = point1 + point2
         self.point1 = point1
@@ -537,7 +528,7 @@ class LineSegment2D(Shape):
             self.edge_style = EdgeStyle()
         else:
             self.edge_style = edge_style
-        super().__init__(type_='linesegment2d', reference_path=reference_path, tooltip=tooltip, name=name)
+        super().__init__(type_='linesegment2d', reference_path=reference_path, name=name)
 
     def bounding_box(self):
         """ Get 2D bounding box of current LineSegment2D. """
@@ -565,7 +556,7 @@ class LineSegment2D(Shape):
         return ax
 
 
-class Wire(Shape):
+class Wire(ReferencedObject):
     """
     A set of connected lines. It also provides highlighting feature.
 
@@ -581,7 +572,8 @@ class Wire(Shape):
                  reference_path: str = "#", name: str = ""):
         self.lines = lines
         self.edge_style = edge_style
-        super().__init__(type_="wire", reference_path=reference_path, tooltip=tooltip, name=name)
+        self.tooltip = tooltip
+        super().__init__(type_="wire", reference_path=reference_path, name=name)
 
     def mpl_plot(self, ax=None, **kwargs):
         """ Plots using matplotlib. """
@@ -596,7 +588,7 @@ class Wire(Shape):
         return ax
 
 
-class Circle2D(Shape):
+class Circle2D(ReferencedObject):
     """
     A circle. It is a primitive and can be instantiated by PrimitiveGroup.
 
@@ -621,7 +613,8 @@ class Circle2D(Shape):
         self.r = r
         self.cx = cx
         self.cy = cy
-        super().__init__(type_='circle', reference_path=reference_path, tooltip=tooltip, name=name)
+        self.tooltip = tooltip
+        super().__init__(type_='circle', reference_path=reference_path, name=name)
 
     def bounding_box(self):
         """ Get 2D bounding box of current Circle2D. """
@@ -651,7 +644,7 @@ class Circle2D(Shape):
         return ax
 
 
-class Rectangle(Shape):
+class Rectangle(ReferencedObject):
     """ Class to draw a rectangle. """
 
     def __init__(self, x_coord: float, y_coord: float, width: float, height: float, edge_style: EdgeStyle = None,
@@ -662,7 +655,8 @@ class Rectangle(Shape):
         self.height = height
         self.surface_style = surface_style
         self.edge_style = edge_style
-        super().__init__(type_='rectangle', reference_path=reference_path, tooltip=tooltip, name=name)
+        self.tooltip = tooltip
+        super().__init__(type_='rectangle', reference_path=reference_path, name=name)
 
     def bounding_box(self):
         """ Get 2D bounding box of current Circle2D. """
@@ -704,7 +698,7 @@ class RoundRectangle(Rectangle):
         self.radius = radius
 
 
-class Point2D(Shape):
+class Point2D(ReferencedObject):
     """
     A class for instantiating a point.
 
@@ -716,12 +710,11 @@ class Point2D(Shape):
     :type point_style: PointStyle
     """
 
-    def __init__(self, cx: float, cy: float, point_style: PointStyle = None, reference_path: str = "#",
-                 tooltip: str = None, name: str = ''):
+    def __init__(self, cx: float, cy: float, point_style: PointStyle = None, reference_path: str = "#", name: str = ''):
         self.cx = cx
         self.cy = cy
         self.point_style = point_style
-        super().__init__(type_='point', reference_path=reference_path, tooltip=tooltip, name=name)
+        super().__init__(type_='point', reference_path=reference_path, name=name)
 
     def bounding_box(self):
         """ Get 2D bounding box of current Circle2D. """
@@ -1121,7 +1114,7 @@ class ScatterMatrix(Figure):
                 for row in sample_attributes for col in sample_attributes]
 
 
-class Arc2D(Shape):
+class Arc2D(ReferencedObject):
     """
     A class for drawing arcs. Arc2D is a primitive and can be instantiated by PrimitiveGroup. By default,
     the arc is drawn anticlockwise.
@@ -1147,7 +1140,7 @@ class Arc2D(Shape):
     """
 
     def __init__(self, cx: float, cy: float, r: float, start_angle: float, end_angle: float, clockwise: bool = None,
-                 edge_style: EdgeStyle = None, reference_path: str = "#", tooltip: str = None, name: str = ''):
+                 edge_style: EdgeStyle = None, reference_path: str = "#", name: str = ''):
         self.cx = cx
         self.cy = cy
         self.r = r
@@ -1155,7 +1148,7 @@ class Arc2D(Shape):
         self.end_angle = end_angle
         self.clockwise = clockwise
         self.edge_style = edge_style
-        super().__init__(type_='arc', reference_path=reference_path, tooltip=tooltip, name=name)
+        super().__init__(type_='arc', reference_path=reference_path, name=name)
 
     def bounding_box(self):
         """ Get 2D bounding box of current Circle2D. """
@@ -1189,7 +1182,7 @@ class Arc2D(Shape):
         return ax
 
 
-class Contour2D(Shape):
+class Contour2D(ReferencedObject):
     """
     A Contour2D is a closed polygon that is formed by multiple primitives.
 
@@ -1209,8 +1202,9 @@ class Contour2D(Shape):
         self.plot_data_primitives = plot_data_primitives
         self.edge_style = edge_style
         self.surface_style = surface_style
+        self.tooltip = tooltip
         self.is_filled = surface_style is not None
-        super().__init__(type_='contour', reference_path=reference_path, tooltip=tooltip, name=name)
+        super().__init__(type_='contour', reference_path=reference_path, name=name)
 
     def bounding_box(self):
         """ Get 2D bounding box of current Contour2D. """
@@ -1510,11 +1504,11 @@ class MultiplePlots(Figure):
         super().__init__(width=width, height=height, type_='multiplot', name=name)
 
 
-def plot_data_path(debug_mode: bool = False, version: str = None):
+def plot_data_path(local: bool = False, version: str = None):
     """ Get path of plot_data package to write it in html file of Figure to draw. """
     version, folder, filename = get_current_link(version=version)
-    if debug_mode:
-        core_path = os.sep.join(__file__.split(os.sep)[:-2] + [folder, filename])
+    if local:
+        core_path = os.sep.join(os.getcwd().split(os.sep)[:-1] + [folder, filename])
         if os.path.isfile(core_path):
             return core_path.replace(" ", "%20")
         print(f'Local compiled {core_path} not found, fall back to CDN')
@@ -1531,7 +1525,7 @@ def make_filepath(filepath: str = None):
     return filepath
 
 
-def plot_canvas(plot_data_object: Figure, filepath: str = None, debug_mode: bool = False, canvas_id: str = 'canvas',
+def plot_canvas(plot_data_object: Figure, filepath: str = None, local: bool = False, canvas_id: str = 'canvas',
                 force_version: str = None, width: float = None, height: float = None):
     """
     Creates a html file and plots input data in web browser.
@@ -1539,9 +1533,9 @@ def plot_canvas(plot_data_object: Figure, filepath: str = None, debug_mode: bool
     :param plot_data_object: a PlotDataObject(ie Scatter, ParallelPlot,\
       MultiplePlots, Graph2D, PrimitiveGroup or PrimitiveGroupContainer)
     :type plot_data_object: PlotDataObject
-    :param debug_mode: uses local library if True, uses typescript \
+    :param local: uses local library if True, uses typescript \
     library from cdn if False
-    :type debug_mode: bool
+    :type local: bool
     :param canvas_id: set canvas' id, ie name
     :type canvas_id: str
     :param width: set the canvas' width:
@@ -1555,7 +1549,7 @@ def plot_canvas(plot_data_object: Figure, filepath: str = None, debug_mode: bool
         plot_data_object.width = width
     if height:
         plot_data_object.height = height
-    plot_data_object.plot(filepath=filepath, debug_mode=debug_mode, canvas_id=canvas_id, version=force_version)
+    plot_data_object.plot(filepath=filepath, local=local, canvas_id=canvas_id, version=force_version)
 
 
 def write_json_for_tests(plot_data_object: PlotDataObject, json_path: str):
